@@ -24,6 +24,7 @@ The most commonly used commands are:
     simple_check            check updating modules simply
     check_refinancing       check refinancing info
     check_refinancing_impl  check refinancing implementation info
+    pull_hedge_fund_nav     pull updated navs of hedge funds
 '''
 
 
@@ -513,6 +514,31 @@ class SurfingEntrance(object):
             wechat_bot = WechatBot()
         wechat_bot.send_update_factor_result(yesterday, 'fund', failed_factors)
 
+    def daily_update_oversea_data(self, yesterday=None, wechat_bot=None):
+        from .data.fund.raw.oversea_data_downloader import OverseaDataUpdate
+        from .data.fund.derived.derived_oversea_nav_analysis import OverseaFundNavAnalysis, RawDataHelper
+
+        if yesterday is None:
+            yesterday = self._get_yesterday()
+
+        failed_factors = []
+        nav_update = OverseaDataUpdate(update_period=10, data_per_page=5)
+        failed_factors.extend(nav_update.update_fund_nav())
+        str_end_date = str(datetime.datetime.now().date())
+        nav_analysis = OverseaFundNavAnalysis(RawDataHelper())
+        nav_analysis.init(str_end_date)
+
+        failed_factors.extend(nav_analysis.process_fund_ret())
+        failed_factors.extend(nav_analysis.process_current_mdd())
+        failed_factors.extend(nav_analysis.process_monthly_ret())
+        failed_factors.extend(nav_analysis.process_period_ret())
+        failed_factors.extend(nav_analysis.process_recent_ret())
+
+        if wechat_bot is None:
+            from .util.wechat_bot import WechatBot
+            wechat_bot = WechatBot()
+        wechat_bot.send_update_factor_result(yesterday, 'oversea', failed_factors)
+
     def check_refinancing(self, yesterday=None, wechat_bot=None):
         from .data.api.raw import RawDataApi
 
@@ -577,6 +603,12 @@ class SurfingEntrance(object):
 
             wechat_bot.send_refinancing_impl_key_info(yesterday, stock_info.to_markdown(), key)
 
+    def pull_hedge_fund_nav(self):
+        from .data.manager.manager_fof import FOFDataManager
+
+        fof_dm = FOFDataManager()
+        fof_dm.pull_hedge_fund_nav()
+
 
 if __name__ == "__main__":
     entrance = SurfingEntrance()
