@@ -320,6 +320,7 @@ class LongShort():
 
         return self._code_name_cache[1][self._code_name_cache[0].get(code, code)]
 
+
 class ExchangeStatus(ReadableEnum):
     """交易状态指标"""
     OPEN = 0
@@ -329,14 +330,14 @@ class ExchangeStatus(ReadableEnum):
 
 
 class FOFTradeStatus(ReadableEnum):
-    PURCHASE = 1
-    SUBSCRIBE = 2
-    REDEEM = 3
-    DIVIDEND_CASH = 4
-    DIVIDEND_VOLUME = 5
-    DEDUCT_REWARD = 6
-    DEDUCT_REWARD_AND_DIVIDEND_VOLUME = 7
-    DEDUCT_REWARD_AND_DIVIDEND_CASH = 8
+    PURCHASE = 1  # 认购
+    SUBSCRIBE = 2  # 申购
+    REDEEM = 3  # 赎回
+    DIVIDEND_CASH = 4  # 现金分红
+    DIVIDEND_VOLUME = 5  # 红利再投
+    DEDUCT_REWARD = 6  # 划扣业绩报酬
+    DEDUCT_REWARD_AND_DIVIDEND_VOLUME = 7  # 划扣业绩报酬且红利再投
+    DEDUCT_REWARD_AND_DIVIDEND_CASH = 8  # 划扣业绩报酬且现金分红
     FORCE_PLUS = 9
     FORCE_MINUS = 10
 
@@ -355,6 +356,8 @@ class FOFStatementStatus(ReadableEnum):
     OUT_ADMINISTRATIVE = 10     # 行政管理费出账
     IN_OTHER_IN = 11            # 其他入账
     OUT_OTHER_OUT = 12          # 其他出账
+    OUT_OTHER_DEBT = 13         # 其他负债
+    IN_OTHER_DEBT_OFFSET = 14   # 其他负债冲抵
 
 
 class FOFTransitStatus(ReadableEnum):
@@ -367,4 +370,3 @@ class FOFOtherRecordStatus(ReadableEnum):
     """FOF其他记录状态"""
     IN = 1
     OUT = 2
-
