@@ -1164,3 +1164,146 @@ class BasicDataApi(metaclass=Singleton):
                 return pd.read_sql(query.statement, query.session.bind)
             except Exception as e:
                 print(f'failed to get_fof_manually <err_msg> {e} from {FOFManually.__tablename__}')
+
+    def get_fof_other_record(self, fof_id_list: Tuple[str] = ()):
+        with BasicDatabaseConnector().managed_session() as db_session:
+            try:
+                query = db_session.query(
+                    FOFOtherRecord,
+                )
+                if fof_id_list:
+                    query = query.filter(
+                        FOFOtherRecord.fof_id.in_(fof_id_list),
+                    )
+                return pd.read_sql(query.statement, query.session.bind)
+            except Exception as e:
+                print(f'failed to get_fof_manually <err_msg> {e} from {FOFOtherRecord.__tablename__}')
+
+    def get_fof_account_statement(self, fof_id_list: Tuple[str] = ()):
+        with BasicDatabaseConnector().managed_session() as db_session:
+            try:
+                query = db_session.query(
+                    FOFAccountStatement,
+                )
+                if fof_id_list:
+                    query = query.filter(
+                        FOFAccountStatement.fof_id.in_(fof_id_list),
+                    )
+                return pd.read_sql(query.statement, query.session.bind)
+            except Exception as e:
+                print(f'failed to get_fof_account_statement <err_msg> {e} from {FOFAccountStatement.__tablename__}')
+
+    def get_fof_incidental_statement(self, fof_id_list: Tuple[str] = ()):
+        with BasicDatabaseConnector().managed_session() as db_session:
+            try:
+                query = db_session.query(
+                    FOFIncidentalStatement,
+                )
+                if fof_id_list:
+                    query = query.filter(
+                        FOFIncidentalStatement.fof_id.in_(fof_id_list),
+                    )
+                return pd.read_sql(query.statement, query.session.bind)
+            except Exception as e:
+                print(f'failed to get_fof_incidental_statement <err_msg> {e} from {FOFIncidentalStatement.__tablename__}')
+
+    def get_fof_investor_position(self, fof_id_list: Tuple[str] = ()):
+        with BasicDatabaseConnector().managed_session() as db_session:
+            try:
+                query = db_session.query(
+                    FOFInvestorPosition,
+                )
+                if fof_id_list:
+                    query = query.filter(
+                        FOFInvestorPosition.fof_id.in_(fof_id_list),
+                    )
+                return pd.read_sql(query.statement, query.session.bind)
+            except Exception as e:
+                print(f'failed to get_fof_manually <err_msg> {e} from {FOFInvestorPosition.__tablename__}')
+
+    def get_fof_estimate_fee(self, fof_id_list: Tuple[str] = ()):
+        with BasicDatabaseConnector().managed_session() as db_session:
+            try:
+                query = db_session.query(
+                    FOFEstimateFee,
+                )
+                if fof_id_list:
+                    query = query.filter(
+                        FOFEstimateFee.fof_id.in_(fof_id_list),
+                    )
+                return pd.read_sql(query.statement, query.session.bind)
+            except Exception as e:
+                print(f'failed to get_fof_estimate_fee <err_msg> {e} from {FOFEstimateFee.__tablename__}')
+
+    def delete_fof_estimate_fee(self, date_to_delete: datetime.date, fof_id_list: List[str]) -> bool:
+        with BasicDatabaseConnector().managed_session() as session:
+            try:
+                session.query(
+                    FOFEstimateFee
+                ).filter(
+                    FOFEstimateFee.fof_id.in_(fof_id_list),
+                    FOFEstimateFee.date == date_to_delete,
+                ).delete(synchronize_session=False)
+                session.commit()
+                return True
+            except Exception as e:
+                print(f'failed to delete data <err_msg> {e} from {FOFEstimateFee.__tablename__}')
+                return False
+
+    def get_fof_estimate_interest(self, fof_id_list: Tuple[str] = ()):
+        with BasicDatabaseConnector().managed_session() as db_session:
+            try:
+                query = db_session.query(
+                    FOFEstimateInterest,
+                )
+                if fof_id_list:
+                    query = query.filter(
+                        FOFEstimateInterest.fof_id.in_(fof_id_list),
+                    )
+                return pd.read_sql(query.statement, query.session.bind)
+            except Exception as e:
+                print(f'failed to get_fof_estimate_interest <err_msg> {e} from {FOFEstimateInterest.__tablename__}')
+
+    def delete_fof_estimate_interest(self, date_to_delete: datetime.date, fof_id_list: List[str]) -> bool:
+        with BasicDatabaseConnector().managed_session() as session:
+            try:
+                session.query(
+                    FOFEstimateInterest
+                ).filter(
+                    FOFEstimateInterest.fof_id.in_(fof_id_list),
+                    FOFEstimateInterest.date == date_to_delete,
+                ).delete(synchronize_session=False)
+                session.commit()
+                return True
+            except Exception as e:
+                print(f'failed to delete data <err_msg> {e} from {FOFEstimateInterest.__tablename__}')
+                return False
+
+    def get_fof_transit_money(self, fof_id_list: Tuple[str] = ()):
+        with BasicDatabaseConnector().managed_session() as db_session:
+            try:
+                query = db_session.query(
+                    FOFTransitMoney,
+                )
+                if fof_id_list:
+                    query = query.filter(
+                        FOFTransitMoney.fof_id.in_(fof_id_list),
+                    )
+                return pd.read_sql(query.statement, query.session.bind)
+            except Exception as e:
+                print(f'failed to get_fof_transit_money <err_msg> {e} from {FOFTransitMoney.__tablename__}')
+
+    def delete_fof_transit_money(self, date_to_delete: datetime.date, fof_id_list: List[str]) -> bool:
+        with BasicDatabaseConnector().managed_session() as session:
+            try:
+                session.query(
+                    FOFTransitMoney
+                ).filter(
+                    FOFTransitMoney.fof_id.in_(fof_id_list),
+                    FOFTransitMoney.confirmed_datetime == date_to_delete,
+                ).delete(synchronize_session=False)
+                session.commit()
+                return True
+            except Exception as e:
+                print(f'failed to delete data <err_msg> {e} from {FOFTransitMoney.__tablename__}')
+                return False
