@@ -617,3 +617,61 @@ class DerivedDataApi(metaclass=Singleton):
             except Exception as e:
                 print(f'failed to delete data <err_msg> {e} from {FOFPosition.__tablename__}')
                 return False
+
+    def get_fof_investor_data(self, fof_id_list: Tuple[str] = ()):
+        with DerivedDatabaseConnector().managed_session() as db_session:
+            try:
+                query = db_session.query(
+                    FOFInvestorData,
+                )
+                if fof_id_list:
+                    query = query.filter(
+                        FOFInvestorData.fof_id.in_(fof_id_list),
+                    )
+                return pd.read_sql(query.statement, query.session.bind)
+            except Exception as e:
+                print(f'failed to get_fof_investor_data <err_msg> {e} from {FOFInvestorData.__tablename__}')
+
+    def delete_fof_investor_data(self, fof_id_to_delete: datetime.date, investor_id_list: List[str]) -> bool:
+        with DerivedDatabaseConnector().managed_session() as session:
+            try:
+                session.query(
+                    FOFInvestorData
+                ).filter(
+                    FOFInvestorData.investor_id.in_(investor_id_list),
+                    FOFInvestorData.fof_id == fof_id_to_delete,
+                ).delete(synchronize_session=False)
+                session.commit()
+                return True
+            except Exception as e:
+                print(f'failed to delete data <err_msg> {e} from {FOFInvestorData.__tablename__}')
+                return False
+
+    def get_fof_position_detail(self, fof_id_list: Tuple[str] = ()):
+        with DerivedDatabaseConnector().managed_session() as db_session:
+            try:
+                query = db_session.query(
+                    FOFPositionDetail,
+                )
+                if fof_id_list:
+                    query = query.filter(
+                        FOFPositionDetail.fof_id.in_(fof_id_list),
+                    )
+                return pd.read_sql(query.statement, query.session.bind)
+            except Exception as e:
+                print(f'failed to get_fof_position_detail <err_msg> {e} from {FOFPositionDetail.__tablename__}')
+
+    def delete_fof_position_detail(self, fof_id_to_delete: datetime.date, fund_id_list: List[str]) -> bool:
+        with DerivedDatabaseConnector().managed_session() as session:
+            try:
+                session.query(
+                    FOFPositionDetail
+                ).filter(
+                    FOFPositionDetail.fund_id.in_(fund_id_list),
+                    FOFPositionDetail.fof_id == fof_id_to_delete,
+                ).delete(synchronize_session=False)
+                session.commit()
+                return True
+            except Exception as e:
+                print(f'failed to delete data <err_msg> {e} from {FOFPositionDetail.__tablename__}')
+                return False
\ No newline at end of file
