@@ -2,6 +2,8 @@
 import datetime
 import traceback
 import json
+import re
+
 import numpy as np
 import pandas as pd
 from typing import List, Dict, Optional, Tuple, Union, Set
@@ -94,12 +96,12 @@ class BasicDataPart1:
         wind_fund_info['track_index'] = wind_fund_info['track_index'].map(lambda x: dic.get(x,'none'))
         self._data_helper._upload_basic(wind_fund_info, FundInfo.__table__.name)
 
-    def fund_info_from_raw(self, fund_id_list: Set[str], benchmark_profile: pd.Series):
+    def fund_info_from_raw(self, fund_id_list: Set[str]):
         def _invest_type_class_to_wind_class_1(x: pd.Series) -> str:
-            if x.invest_type_class == '其他基金':
+            if x.invest_type_class_1 == '其他基金':
                 if 'QDII' in x.desc_name:
                     return '国际(QDII)基金'
-            return x.invest_type_class
+            return x.invest_type_class_1
 
         def _invest_type_class_to_wind_class_2(x: pd.Series) -> str:
             '''Choice的基金二级类型转换为wind的'''
@@ -114,7 +116,16 @@ class BasicDataPart1:
                 return '混合债券型二级基金'
             elif x.invest_type_class_1 == '债券型基金' and x.invest_type_class_2 == '被动指数型基金':
                 return '被动指数型债券基金'
-            elif x.invest_type_class_2 in ('QDII基金', '封闭式基金', '保本型基金'):
+            elif x.invest_type_class_2 == 'QDII基金':
+                if x.invest_type_class_1 == '债券型基金':
+                    return '国际(QDII)债券型基金'
+                elif x.invest_type_class_1 == '股票型基金':
+                    return '国际(QDII)股票型基金'
+                elif x.invest_type_class_1 == '混合型基金':
+                    return '国际(QDII)混合型基金'
+                # error case
+                return
+            elif x.invest_type_class_2 in ('封闭式基金', '保本型基金'):
                 # error case
                 return
             else:
@@ -138,12 +149,12 @@ class BasicDataPart1:
             try:
                 return fund_tag(x.base_fund_id, x.desc_name, x.is_open, x.currency, x.wind_class_2, benchmark.at[x.wind_id, 'benchmark_s_raw'], x.fund_id)
             except KeyError:
-                print(f'{x.fund_id} has no benchmark info')
+                print(f'{x.fund_id} no benchmark info')
                 return
 
         def _lambda_fund_manager(x: str) -> pd.Series:
             manager_list: List[str] = x.split(',')
-            return pd.Series(['\r\n'.join(manager_list), manager_list[0]])
+            return pd.Series(['\r\n'.join(manager_list), re.sub(r'\(.*\)$', '', manager_list[0])])
 
         def _lambda_benchmark(x: str) -> pd.Series:
             def _parse_index(part: str):
@@ -163,7 +174,7 @@ class BasicDataPart1:
 
             if x is None:
                 return
-            benchmarks: List[str] = x.split('+')
+            benchmarks: List[str] = str(x).split('+')
             if len(benchmarks) == 1:
                 second = None
             else:
@@ -189,25 +200,36 @@ class BasicDataPart1:
                         return
                 return value
 
-            fee = em_fund_fee.loc[x, ['manage_fee', 'trustee_fee', 'purchase_fee', 'redeem_fee']]
-            return fee.transform(_parse_fee)
+            try:
+                fee = em_fund_fee.loc[x, ['manage_fee', 'trustee_fee', 'purchase_fee', 'redeem_fee']]
+            except KeyError:
+                return pd.Series()
+            else:
+                return fee.transform(_parse_fee)
 
+        benchmark = RawDataApi().get_em_fund_benchmark()
+        if benchmark is None:
+            return
+        benchmark = benchmark[benchmark.em_id.isin(fund_id_list)]
+        benchmark = benchmark.sort_values(by=['em_id', 'datetime']).drop_duplicates(subset='em_id', keep='last')
+        benchmark = benchmark.set_index('em_id')
         # 获取raw中的基金基础信息
-        df = self._raw_data_api.get_em_fund_info(fund_id_list).drop(columns='_update_time')
+        df = RawDataApi().get_em_fund_info(fund_id_list).drop(columns='_update_time')
+        if df is None:
+            return
         # 其中一部分列可以直接使用，改一下名字即可
         df = df.rename(columns={'em_id': 'wind_id', 'name': 'desc_name', 'manager_id': 'pre_fund_manager'})
         # is open
         df['is_open'] = 1
-        key_words = ['封闭','定期','定开']
+        key_words = ['封闭', '定期', '定开']
         key_words = '|'.join(key_words)
         _wind_ids = df[df['desc_name'].str.contains(key_words)].wind_id
         df = df.set_index('wind_id')
-        df.loc[_wind_ids,'is_open'] = 0
+        df.loc[_wind_ids, 'is_open'] = 0
         df = df.reset_index()
         # 没有end_date的话给一个默认值
         df['end_date'] = df['end_date'].where(df.end_date.notna(), '2040-12-31')
-        # 这里可能还需要加上港币
-        df['currency'] = df.currency.map({'人民币元': 'CNY', '美元': 'USD'})
+        df['currency'] = df.currency.map({'人民币元': 'CNY', '美元': 'USD', '港元': 'HKD', '港币': 'HKD'})
         # 基金经理
         df[['manager_id', 'fund_manager']] = df.pre_fund_manager.apply(_lambda_fund_manager)
         # 新基金都是!0，这里需要检查是否有相同order_book_id的旧基金
@@ -215,20 +237,20 @@ class BasicDataPart1:
         df['transition'] = 0
         df['fund_id'] = df.order_book_id.transform(lambda x: x + '!0')
         # Choice的基金一二级分类转换为wind的
-        df['wind_class_1'] = df[['desc_name', 'invest_type_class_2']].transform(_invest_type_class_to_wind_class_1, axis=1)
-        df['wind_class_2'] = df[['invest_type_class_1', 'invest_type_class_2']].transform(_invest_type_class_to_wind_class_2, axis=1)
+        df['wind_class_1'] = df[['desc_name', 'invest_type_class_1']].apply(_invest_type_class_to_wind_class_1, axis=1)
+        df['wind_class_2'] = df[['invest_type_class_1', 'invest_type_class_2']].apply(_invest_type_class_to_wind_class_2, axis=1)
         df['asset_type'] = df.apply(lambda x: self._find_tag(x.desc_name, x.wind_class_2), axis=1)
         df['structure_type'] = df.apply(_lambda_structure_type, axis=1)
         df['is_etf'] = df.desc_name.transform(lambda x: 1 if ('ETF' in x and '联接' not in x) else 0)
         fund_benchmark = self._basic_data_api.get_fund_benchmark(fund_id_list).set_index('em_id')
         df['index_id_new'] = df.apply(_lambda_index_id_new, axis=1, benchmark=fund_benchmark)
         em_fund_fee = self._raw_data_api.get_em_fund_fee(fund_id_list).drop(columns='_update_time').set_index('em_id')
-        df[['manage_fee', 'trustee_fee', 'purchase_fee', 'redeem_fee']] = df.wind_id.transform(_lambda_fee, em_fund_fee=em_fund_fee)
+        df[['manage_fee', 'trustee_fee', 'purchase_fee', 'redeem_fee']] = df.wind_id.apply(_lambda_fee, em_fund_fee=em_fund_fee)
         df = df.set_index('wind_id').join(em_fund_fee[['subscr_fee', 'purchase_fee', 'redeem_fee', 'service_fee']].rename(columns={'subscr_fee': 'subscr_fee_detail', 'purchase_fee': 'purchase_fee_detail', 'redeem_fee': 'redeem_fee_detail'}))
-        df['benchmark'] = benchmark_profile
+        df['benchmark'] = benchmark.benchmark
         # 拆解上边的benchmark
         df[['benchmark_1', 'benchmark_2']] = df.benchmark.apply(_lambda_benchmark)
-        df = df.drop(columns='invest_type_class_2').reset_index()
+        df = df.drop(columns=['invest_type_class_1', 'invest_type_class_2']).reset_index()
         # 将场内变为场外的
         df['wind_id'] = df.wind_id.transform(lambda x: x.split('.')[0] + '.OF' if '.OF' not in x else x)
         self._data_helper._upload_basic(df, FundInfo.__table__.name)
@@ -355,11 +377,206 @@ class BasicDataPart1:
             traceback.print_exc()
             return False
 
-    def fund_benchmark(self):
-        df = pd.read_csv('./data/benchmark_res2.csv')
-        df = df[['fund_id', 'fund_em_id', 'benchmark', 'index_text', 'assets', 'industry']].rename(columns={'fund_em_id': 'em_id'})
+    def fund_benchmark(self, end_date: str = '', is_history=True):
+        def _parse_raw_benchmark(x: str):
+            if '×' in x:
+                x.split('x')
+            elif '*' in x:
+                x.split('*')
+
+        raw_fund_bc = RawDataApi().get_em_fund_benchmark(end_date)
+        now_fund_bc = BasicDataApi().get_fund_benchmark()
+        to_insert = set(raw_fund_bc.em_id.array) - set(now_fund_bc.em_id.array)
+        if not to_insert and is_history:
+            return
+        if is_history:
+            raw_fund_bc = raw_fund_bc[raw_fund_bc.em_id.isin(to_insert)]
+            df = raw_fund_bc.set_index('em_id').benchmark.transform(_parse_raw_benchmark)
+        else:
+            pass
         self._data_helper._upload_basic(df, FundBenchmark.__table__.name)
 
+    def fund_benchmark_parser(self, file_path: str):
+        from sympy import simplify
+
+        _CHAR_TO_BE_REPLACED = {
+            ' ': '',
+            '*+': '+',
+            '×*': '*',
+            '╳': '*',
+            'X': '*',
+            '%8': '%',
+            '×': '*',
+            '本基金的业绩比较基准为:': '',
+            '互联网+': '互联网PLUS',
+            'AA+': 'AAPLUS',
+            'DJ-AIGCommodity': 'DJAIGCommodity',
+            '500信息技术': '中证500信息技术',
+            '180治理': '上证180治理',
+            'A-H50': 'AH50',
+            '中债-综合财富': '中债综合财富',
+            '中债-综合全价': '中债综合全价',
+            '中债-综合指数': '中债综合指数',
+            '中债-广西壮族自治区': '中债广西壮族自治区',
+            '中债-总财富': '中债总财富',
+            '中债-总全价': '中债总全价',
+            '中债-新综合财富': '中债新综合财富',
+            '中债-农发行': '中债农发行',
+            '中债-安徽省': '中债安徽省',
+            '中债-信用债': '中债信用债',
+            '中债-国债及政策性银行债': '中债国债及政策性银行债',
+            '中债-湖北省': '中债湖北省',
+            '中债-金融债券总全价': '中债金融债券总全价',
+            '中债-新中期票据': '中债新中期票据',
+            '中债-市场隐含评级': '中债市场隐含评级',
+            '道琼斯-美国国际集团': '道琼斯美国国际集团',
+            '-0-3年': '零至三年',
+            '-0-2年': '零至二年',
+            '-0-5年': '零至五年',
+            '-1-3年': '一至三年',
+            '-1-5年': '一至五年',
+            '-3-5年': '三至五年',
+            '-5-10年': '五至十年',
+            '-7-10年': '七至十年',
+            '1-3年': '一至三年',
+            '1-7年': '一至七年',
+            '0-1年': '零至一年',
+            '0-3年': '零至三年',
+            '0-4年': '零至四年',
+            '3-5年': '三至五年',
+            '5-10年': '五至十年',
+            '5-8年': '五至八年',
+            '8-10年': '八至十年',
+            '-5年': '五年',
+            '-10年': '十年',
+            '1三年': '三年',
+            '7天': '七天',
+            '3个月': '三个月',
+            '6个月': '六个月',
+            '1年': '一年',
+            '2年': '二年',
+            '3年': '三年',
+            '4.0': '',
+            '(税后)': '',
+        }
+        _CHAR_TO_BE_REPLACED_BY_RE = {
+            r'[\[\];:”,\x7f]': r'',
+            r'x(\d+\%)': r'*\1',
+            r'\n.*': r'',
+            r'^年化收益率|固定业绩基准(\d+\%)$': r'\1',
+            r'^(\d+\%)\/年$': r'\1',
+            r'[\(\（][^\-\+]*?[\)\）]': r'',
+            r'A[uU]\d+\.\d+': r'',
+            r'(\d+\%)的': r'\1*',
+            r'^(.+?)[\*\×]?(\d+\%)\+(.+?)[\*\×]?(\d+\%)$': r'\1*\2+\3*\4',
+            r'^(.+?)[\*\×]?(\d+\%)\+(.+?)[\*\×]?(\d+\%)\+(.+?)[\*\×]?(\d+\%)$': r'\1*\2+\3*\4+\5*\6',
+            r'^(\d+\%)[\*\×]?(.+)\+(\d+\%)[\*\×]?(.+)$': r'\1*\2+\3*\4',
+            r'^(\d+\%)[\*\×]?(.+)\+(\d+\%)[\*\×]?(.+)\+(\d+\%)[\*\×]?(.+)$': r'\1*\2+\3*\4+\5*\6',
+            r'\%': r'/100',
+        }
+
+        def _parse_raw_benchmark(x: pd.Series):
+            r = {}
+            if pd.isnull(x.BENCHMARK):
+                # print(x)
+                return json.dumps({'-1': -1})
+
+            normalized = x.BENCHMARK
+            for k, v in _CHAR_TO_BE_REPLACED.items():
+                normalized = normalized.replace(k, v)
+            for k, v in _CHAR_TO_BE_REPLACED_BY_RE.items():
+                normalized = re.sub(k, v, normalized)
+
+            try:
+                # print(x.name, normalized, x.BENCHMARK)
+                normalized = str(simplify(normalized).evalf(strict=True))
+            except Exception as e:
+                if '+' in normalized:
+                    if 'X' not in x.BENCHMARK and 'I' not in x.BENCHMARK and 'S' not in x.BENCHMARK and '下滑曲线值' not in x.BENCHMARK:
+                        print(f'x {normalized} {x.BENCHMARK} {e}')
+                    return json.dumps({'-1': -1})
+            parts = normalized.split('+')
+            for i in range(len(parts)):
+                try:
+                    value = x.at[f'BMINDEXCODE_{i+1}']
+                except KeyError:
+                    print(f'1 {normalized}')
+                else:
+                    if pd.isnull(value):
+                        try:
+                            r['1'] = float(parts[i])
+                            continue
+                        except Exception:
+                            if '银行活期存款利率' in parts[i] or '银行活期存款税后收益率' in parts[i]:
+                                value = 'RA0000.IR'
+                            elif '利差' not in x.BENCHMARK and x.name not in ('000988.OF', '000989.OF', '000990.OF', '006585.OF', '007272.OF', '007976.OF', '007977.OF', '007978.OF',
+                                                                            '008142.OF', '008143.OF', '008701.OF', '008702.OF', '009198.OF', '159812.OF', '161116.OF', '164701.OF',
+                                                                            '202101.OF', '253010.OF', '518660.OF', '518850.OF'):
+                                print(f'2 {x.name} {i+1} {normalized} {x.BENCHMARK}')
+                                continue
+                    value_parts = parts[i].split('*')
+                    if len(value_parts) not in (1, 2):
+                        if len(value_parts) == 3:
+                            for one in value_parts:
+                                if '汇率' in one:
+                                    value_parts.remove(one)
+                                    break
+                            else:
+                                if 'X' not in x.BENCHMARK and '下滑曲线值' not in x.BENCHMARK and 'A%' not in x.BENCHMARK and 'B%' not in x.BENCHMARK:
+                                    print(f'4 {normalized} {x.BENCHMARK}')
+                                continue
+                        else:
+                            if 'X' not in normalized and '人民币/港币汇率' not in x.BENCHMARK:
+                                print(f'3 {normalized} {x.BENCHMARK}')
+                            continue
+
+                    if len(value_parts) == 1:
+                        r[value] = 1
+                    else:
+                        try:
+                            if '活期存款' in value_parts[0] or '七天通知存款' in value_parts[0] or '一年期定期' in value_parts[0] or '一年期银行定期' in value_parts[0] or '六个月银行定期' in value_parts[0]:
+                                r[value] = 1
+                            else:
+                                r[value] = float(value_parts[0])
+                        except Exception:
+                            if 'm' not in x.BENCHMARK and 'n' not in x.BENCHMARK and 'I' not in x.BENCHMARK and '人民币/港币汇率' not in x.BENCHMARK:
+                                print(x.name, x.BENCHMARK, normalized, value_parts)
+            return json.dumps({k: v for k, v in zip(r.keys(), sorted(r.values(), reverse=True))})
+
+        df = pd.read_csv(file_path, header=0, index_col=1)
+        r = df.apply(_parse_raw_benchmark, axis=1)
+        return df, r
+
+    def recalc_all_funds_benchmark(self, path: str):
+        def replaced_with_index_id(x):
+            if not pd.isnull(x.benchmark):
+                replaced = {}
+                b = json.loads(x.benchmark)
+                for k, v in b.items():
+                    if k == '1':
+                        replaced[k] = v
+                    else:
+                        try:
+                            replaced[em_id_to_index_id[k.upper()]] = v
+                        except KeyError:
+                            if '-1' not in replaced:
+                                replaced['-1'] = v
+                            else:
+                                replaced['-1'] += v
+                return json.dumps(replaced)
+
+        r = self.fund_benchmark_parser(path)
+        all_funds_benchmark = pd.concat([r[0].BENCHMARK.rename('index_text'), r[1].rename('benchmark')], axis=1)
+        index_info = BasicDataApi().get_index_info()
+        em_id_to_index_id = index_info.set_index('em_id')['index_id'].to_dict()
+        all_funds_benchmark['benchmark_s_raw'] = all_funds_benchmark.apply(replaced_with_index_id, axis=1)
+        now_fund_benchmark = BasicDataApi().get_fund_benchmark()
+        whole_funds_benchmark = all_funds_benchmark.join(now_fund_benchmark.set_index('em_id')[['assets', 'industry']], how='outer')
+        whole_funds_benchmark['benchmark_s'] = whole_funds_benchmark.benchmark_s_raw
+        whole_funds_benchmark['fund_id'] = whole_funds_benchmark.apply(lambda x: x.name.split('.')[0] + '!0', axis=1)
+        # TODO asset and industry
+        BasicDataHelper()._upload_basic(whole_funds_benchmark.rename_axis(index='em_id').reset_index(), FundBenchmarkNew.__table__.name)
+
     def index_price(self, start_date, end_date):
         try:
             raw_start_date_dt: datetime.date = pd.to_datetime(start_date, infer_datetime_format=True).date()
@@ -378,6 +595,12 @@ class BasicDataPart1:
             yahoo_index_price = self._raw_data_api.get_yahoo_index_price_df(start_date, end_date).drop(columns=['_update_time'])
             index_info_df = self._index_info_df[self._index_info_df.price_source == IndexPriceSource.default]
             em_id_list: Dict[str, str] = index_info_df[['em_id', 'index_id']].dropna().set_index('em_id').to_dict()['index_id']
+            # 这几个指数需要从yahoo下载数据 因为每日更新时choice还没有数据
+            for index in ('DJIA.GI', 'FTSE.GI', 'IXIC.GI'):
+                try:
+                    del em_id_list[index]
+                except KeyError:
+                    pass
             em_index_price = self._raw_data_api.get_em_index_price(start_date, end_date, em_id_list.keys()).drop(columns=['_update_time'])
             df_list = []
             # 处理Choice数据
@@ -432,6 +655,14 @@ class BasicDataPart1:
 
             df_list.append(cxindex_index_price[cxindex_index_price.datetime == end_date_dt])
             # 存进去美元计价的数据
+            yahoo_index_price = yahoo_index_price[yahoo_index_price.index_id != 'n225']
+
+            # yahoo下载的指数名字与我们自己的指数名字做一下转换
+            naming_dict = {
+                'ftse100': 'gi_ftse100',
+                'ixic': 'nasdaq'
+            }
+            yahoo_index_price['index_id'] = yahoo_index_price.index_id.map(lambda x: naming_dict[x] if x in naming_dict else x)
             df_list.append(yahoo_index_price[yahoo_index_price.datetime.between(raw_start_date_dt, end_date_dt)])
 
             df = pd.concat(df_list, ignore_index=True)
@@ -1307,3 +1538,4 @@ if __name__ == '__main__':
     # bdp.index_component()
     # bdp.fund_rate('20200812')
     # bdp.fund_size_hold_rate_history()
+    # bdp.recalc_all_funds_benchmark('/Users/ido/Downloads/new_funds_benchmark_info.csv')
