@@ -330,7 +330,7 @@ class S3RetrieverForDM(S3ETLTool):
             if field.type != pd.DataFrame:
                 continue
             # 以下df理论上没必要保存，可以自己生成出来且较快
-            if field.name == 'index_fund_indicator_pack':
+            if field.name in ['index_fund_indicator_pack','stock_ipo_data','conv_bond_ipo_data','stock_ipo_data_detail','conv_bond_ipo_data_detail','stock_ipo_info','conv_bond_ipo_info']:
                 continue
             name = field.name
 
@@ -381,6 +381,8 @@ class S3RetrieverForDM(S3ETLTool):
                 elif name in ('fund_index_map', 'fund_end_date_dict'):
                     df = pd.read_parquet(f'{self._s3_bucket_uri}/_ndf_{name}.parquet')
                     data = df.to_dict()[name]
+                elif name in ('stock_ipo_data','conv_bond_ipo_data','stock_ipo_data_detail','conv_bond_ipo_data_detail','stock_ipo_info','conv_bond_ipo_info'):
+                    data = {}
                 else:
                     raise FileNotFoundError(f'do not support retrieve this data {name} from s3')
                 dm.dts.__dict__[name] = data
