@@ -141,6 +141,14 @@ class HedgeFundNAVReader:
         df['datetime'] = df.datetime.transform(lambda x: pd.to_datetime(str(x), infer_datetime_format=True).date())
         return df
 
+    @staticmethod
+    def _read_for_BoPu6(file_path: str) -> pd.DataFrame:
+        df = pd.read_excel(file_path)
+        df = df.loc[:, ['产品名称', '产品代码', '业务日期', '单位净值', '累计单位净值', '虚拟后净值']]
+        df = df.rename(columns=HedgeFundNAVReader.COLUMNS_DICT)
+        df['datetime'] = df.datetime.transform(lambda x: pd.to_datetime(str(x), infer_datetime_format=True).date())
+        return df
+
     def _notify_error_event(self, err_msg: str):
         print(f'[read_navs_and_dump_to_db] {err_msg}')
         self._wechat_bot.send_hedge_fund_nav_update_failed(err_msg)
@@ -194,6 +202,8 @@ class HedgeFundNAVReader:
                         df = HedgeFundNAVReader._read_for_TaiChuangXiShuoCTANormalWithPrism(file_path)
                     else:
                         df = HedgeFundNAVReader._read_for_TaiChuangXiShuoCTANormal(file_path)
+                elif '博普量化对冲6号' in name:
+                    df = HedgeFundNAVReader._read_for_BoPu6(file_path)
                 else:
                     raise NotImplementedError('unknown hedge fund nav file from attachment')
             except Exception as e:
@@ -224,7 +234,7 @@ class HedgeFundNAVReader:
                 self._notify_error_event(f'{e} (concat)')
                 return
             else:
-                self._wechat_bot.send_hedge_fund_nav_update(whole_df)
+                # self._wechat_bot.send_hedge_fund_nav_update(whole_df)
                 print(f'[read_navs_and_dump_to_db] done (uid_last){uid_last_succeed} (df){whole_df}')
         else:
             whole_df = None
