@@ -1,4 +1,6 @@
 
+import datetime
+
 from sqlalchemy import CHAR, Column, Integer, Index, BOOLEAN, text, TEXT, Enum, VARCHAR
 from sqlalchemy.ext.declarative import declarative_base
 from sqlalchemy.dialects.mysql import DOUBLE, DATE, TINYINT, SMALLINT, DATETIME, MEDIUMTEXT
@@ -11,8 +13,8 @@ class Base:
 
 
 class FOFBase:
-    create_time = Column(DATETIME, nullable=False, server_default=text('CURRENT_TIMESTAMP'))  # 创建时间
-    update_time = Column(DATETIME, nullable=False, server_default=text('CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP'))  # 更新时间
+    create_time = Column(DATETIME, nullable=False, default=datetime.datetime.now)  # 创建时间
+    update_time = Column(DATETIME, nullable=False, default=datetime.datetime.now, onupdate=datetime.datetime.now)  # 更新时间
     is_deleted = Column(BOOLEAN, nullable=False, server_default=text('FALSE'))  # 是否删除 默认不删除
 
 
@@ -815,7 +817,6 @@ class HedgeFundInfo(FOFBase):
     adjusted_net_value = Column(DOUBLE(asdecimal=False))                             # 复权净值
     invest_strategy = Column(VARCHAR(256))                                           # 投资策略
     manager_id = Column(CHAR(16), nullable=False)  # 私募基金公司ID
-    water_line = Column(DOUBLE(asdecimal=False))  # 初始水位线 todo 待删除
     incentive_fee_mode = Column(TEXT)  # 业绩报酬计提方法
     incentive_fee_ratio = Column(DOUBLE(asdecimal=False))  # 业绩计提比例
     incentive_fee_type = Column(VARCHAR(31))                                          # 业绩提取方式
@@ -826,7 +827,7 @@ class HedgeFundInfo(FOFBase):
     manager = Column(TEXT)  # 私募基金经理
     stars = Column(Integer, server_default=text('1'))  # 星级
     lock_in_period = Column(Integer)                                                    # 封闭期
-    found_date = Column(CHAR(20))                                                       # 成立时间
+    found_date = Column(DATE)                                                           # 成立时间
     fund_adviser = Column(VARCHAR(31))                                                  # 投资顾问
     records_no = Column(VARCHAR(127))                                                   # 备案编号
     records_date = Column(CHAR(20))                                                     # 备案日期
@@ -843,6 +844,11 @@ class HedgeFundInfo(FOFBase):
     purchase_done = Column(Integer)                                                     # 申购交收
     redeem_confirmed = Column(Integer)                                                  # 赎回确认
     redeem_done = Column(Integer)                                                       # 赎回交收
+    latest_cal_date = Column(DATETIME)                                                  # 最新净值日
+    mdd = Column(DOUBLE(asdecimal=False))                                               # 最大回撤
+    ret = Column(DOUBLE(asdecimal=False))                                               # 成立以来收益率
+    year_to_now_ret = Column(DOUBLE(asdecimal=False))                                   # 今年以来收益率
+    ann_ret = Column(DOUBLE(asdecimal=False))                                           # 年化收益率
 
 
 # class HedgeFundMgrInfo(Base):
@@ -884,6 +890,7 @@ class FOFInfo(FOFBase):
     acc_unit_value = Column(DOUBLE(asdecimal=False))  # 累计净值
     adjusted_net_value = Column(DOUBLE(asdecimal=False))  # 复权净值
     is_calculating = Column(BOOLEAN, default=False)       # 是否正在计算
+    latest_cal_date = Column(DATETIME)                      # 最新净值日
 
 
 class FOFScaleAlteration(FOFBase):
@@ -893,12 +900,15 @@ class FOFScaleAlteration(FOFBase):
 
     id = Column(Integer, primary_key=True, autoincrement=True)
     fof_id = Column(CHAR(16), primary_key=True)  # 产品ID
-    datetime = Column(DATE, primary_key=True)  # 日期
+    datetime = Column(DATE, primary_key=True)  # 确认日期
     investor_id = Column(CHAR(16), nullable=False)  # 投资人ID
-    confirmed_date = Column(DATE)  # 确认日期
-    deposited_date = Column(DATE)  # 入账日期
+    applied_date = Column(DATE)  # 申请日期
+    deposited_date = Column(DATE)  # 交割日期
     amount = Column(DOUBLE(asdecimal=False))  # 被申购金额
     share = Column(DOUBLE(asdecimal=False))  # 被赎回份额
+    nav = Column(DOUBLE(asdecimal=False))  # 交易净值
+    status = Column(Integer, nullable=False)  # 状态：在途/完成
+    event_type = Column(Integer)                            # 交易类型
     unit_total = Column(DOUBLE(asdecimal=False))  # 确认份额
     asset_type = Column(Enum(HoldingAssetType), nullable=False)  # 资产类型
 
@@ -919,6 +929,7 @@ class FOFAssetAllocation(FOFBase):
     nav = Column(DOUBLE(asdecimal=False))                           # 交易净值
     status = Column(Enum(FundStatus), nullable=False)               # 状态：在途/完成
     confirmed_date = Column(DATE)                                   # 确认日期
+    deposited_date = Column(DATE)                                   # 交割日期
     event_type = Column(Integer)                                    # 事件类型
     unit_total = Column(DOUBLE(asdecimal=False))                    # 确认份额
     water_line = Column(DOUBLE(asdecimal=False))                    # 水位线(累计净值)
