@@ -248,7 +248,7 @@ class ReportHelper:
             rank_pct = (_fund_list.index(i.Index) + 1) / len(_fund_list) if i.Index in _fund_list else 1
             fund_rank.append(rank_i)
             fund_rank_pct.append(rank_pct)
-            _fund_nav_recent_month = self.fund_nav.loc[last_month_start_day:][_fund_list]
+            _fund_nav_recent_month = self.fund_nav.loc[last_month_start_day:][self.fund_nav.columns.intersection(set(_fund_list))]
             _fund_ret_recent = _fund_nav_recent_month.iloc[-1] / _fund_nav_recent_month.iloc[0]
             r = np.mean([_fund_ret_recent >= _index_ret_recent[i.index_id]])
             fund_vs_index_rate[i.index_id] = r
@@ -567,7 +567,7 @@ class ReportHelper:
         index_val_df = pd.concat(_res, axis=1, sort=True)
         index_val_dic = {k : f'{k}_{v}' for k,v in TaaTunerParam.PCT_PAIR.items()}
         index_val_df = index_val_df.loc[dt:].rename(columns=index_val_dic)
-        df = pct_df.loc[dt:]
+        df = pct_df.loc[dt:].ffill()
         HybridPainter.plot_taa_detail(df, '指数估值分位数')
         HybridPainter.plot_taa_detail(index_val_df, '指数估值')
         
@@ -907,7 +907,7 @@ class ReportHelper:
         top_fund_list = fund_ret[fund_ret.ret > index_ret].sort_values('ret',ascending=False).head(6).index.tolist()
         pos_funds = res_df[res_df.index_id==index_id].index.tolist()
         top_fund_list = list(set(top_fund_list).union(set(pos_funds)))
-        price_df = _index_price[[index_id]].join(fund_nav_week[top_fund_list])
+        price_df = _index_price[[index_id]].join(fund_nav_week[fund_nav_week.columns.intersection(set(top_fund_list))])
         price_df = price_df / price_df.iloc[0]
         name_dict = fund_info.set_index('fund_id').to_dict()['desc_name']
         name_dict.update(index_info.set_index('index_id').to_dict()['desc_name'])
